Changes in XlsxWriter — XlsxWriter Documentation

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »

# Changes in XlsxWriter

This section shows changes and bug fixes in the XlsxWriter module.

## Release 0.2.8 - April 4 2013

- Added worksheet outlines and grouping. See Working with Outlines and Grouping.

## Release 0.2.7 - April 3 2013

- Added `set_default_row()` method. See Example: Hiding Rows and Columns.
- Added hide_row_col.py, hide_sheet.py and text_indent.py examples.

## Release 0.2.6 - April 1 2013

- Added `freeze_panes()` and `split_panes()` methods. See Example: Freeze Panes and Split Panes .
- Added `set_selection()` method to select worksheet cell or range of cells.

## Release 0.2.5 - April 1 2013

- Added additional `Workbook()` parameters `'tmpdir'` and `'date_1904'`.

## Release 0.2.4 - March 31 2013

- Added `Workbook()` `'constant_memory'` constructor property to minimise memory usage when writing large files. See Working with Memory and Performance for more details.
- Fixed bug with handling of UTF-8 strings in worksheet names (and probably some other places as well). Reported by Josh English.
- Fixed bug where temporary directory used to create xlsx files wasn’t cleaned up after program close.

## Release 0.2.3 - March 27 2013

- Fixed bug that was killing performance for medium sized files. The module is now 10x faster than previous versions. Reported by John Yeung.

## Release 0.2.2 - March 27 2013

- Added worksheet data validation options. See the `data_validation()` method, Working with Data Validation and Example: Data Validation and Drop Down Lists.
- There are now over 600 unit tests including more than 130 tests that compare against the output of Excel.

## Release 0.2.1 - March 25 2013

- Added support for datetime.datetime, datetime.date and datetime.time to the `write_datetime()` method. GitHub issue #3. Thanks to Eduardo (eazb) and Josh English for the prompt.

## Release 0.2.0 - March 24 2013

- Added conditional formatting. See the `conditional_format()` method, Working with Conditional Formatting and Example: Conditional Formatting.

## Release 0.1.9 - March 19 2013

- Added Python 2.6 support. All tests now pass in the following versions:

  > - Python 2.6
  > - Python 2.7.2
  > - Python 2.7.3
  > - Python 3.1
  > - Python 3.2
  > - Python 3.3.0

## Release 0.1.8 - March 18 2013

- Fixed Python 3 support.

## Release 0.1.7 - March 18 2013

- Added the option to write cell comments to a worksheet. See `write_comment()` and Working with Cell Comments.

## Release 0.1.6 - March 17 2013

- Added `insert_image()` worksheet method to support inserting PNG and JPEG images into a worksheet. See also the example program Example: Inserting images into a worksheet.
- There are now over 500 unit tests including more than 100 tests that compare against the output of Excel.

## Release 0.1.5 - March 10 2013

- Added the `write_rich_string()` worksheet method to allow writing of text with multiple formats to a cell. Also added example program: Example: Writing “Rich” strings with multiple formats.
- Added the `hide()` worksheet method to hide worksheets.
- Added the `set_first_sheet()` worksheet method.

## Release 0.1.4 - March 8 2013

- Added the `protect()` worksheet method to allow protection of cells from editing. Also added example program: Example: Enabling Cell protection in Worksheets.

## Release 0.1.3 - March 7 2013

- Added worksheet methods:

  > - `set_zoom()` for setting worksheet zoom levels.
  > - `right_to_left()` for middle eastern versions of Excel.
  > - `hide_zero()` for hiding zero values in cells.
  > - `set_tab_color()` for setting the worksheet tab colour.

## Release 0.1.2 - March 6 2013

- Added autofilters. See Working with Autofilters for more details.
- Added the `write_row()` and `write_column()` worksheet methods.

## Release 0.1.1 - March 3 2013

- Added the `write_url()` worksheet method for writing hyperlinks to a worksheet.

## Release 0.1.0 - February 28 2013

- Added the `set_properties()` workbook method for setting document properties.

- Added several new examples programs with documentation. The examples now include:

  > - array_formula.py
  > - cell_indentation.py
  > - datetimes.py
  > - defined_name.py
  > - demo.py
  > - doc_properties.py
  > - headers_footers.py
  > - hello_world.py
  > - merge1.py
  > - tutorial1.py
  > - tutorial2.py
  > - tutorial3.py
  > - unicode_polish_utf8.py
  > - unicode_shift_jis.py

## Release 0.0.9 - February 27 2013

- Added the `define_name()` method to create defined names and ranges in a workbook or worksheet.
- Added the `worksheets()` method as an accessor for the worksheets in a workbook.

## Release 0.0.8 - February 26 2013

- Added the `merge_range()` method to merge worksheet cells.

## Release 0.0.7 - February 25 2013

- Added final page setup methods to complete the page setup section.

  > - print_area()
  > - fit_to_pages()
  > - set_start_page()
  > - set_print_scale()
  > - set_h_pagebreaks()
  > - set_v_pagebreaks()

## Release 0.0.6 - February 22 2013

- Added page setup method.

  > - print_row_col_headers

## Release 0.0.5 - February 21 2013

- Added page setup methods.

  > - repeat_rows()
  > - repeat_columns()

## Release 0.0.4 - February 20 2013

- Added Python 3 support with help from John Evans. Tested with:

  > - Python-2.7.2
  > - Python-2.7.3
  > - Python-3.2
  > - Python-3.3.0

- Added page setup methods.

  > - center_horizontally()
  > - center_vertically()
  > - set_header()
  > - set_footer()
  > - hide_gridlines()

## Release 0.0.3 - February 19 2013

- Added page setup method.

  > - set_margins()

## Release 0.0.2 - February 18 2013

- Added page setup methods.

  > - set_landscape()
  > - set_portrait()
  > - set_page_view()
  > - set_paper()
  > - print_across()

## Release 0.0.1 - February 17 2013

- First public release.

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »